@@ -67,7 +67,7 @@ class Stream(Generic[_T]):
     def find_first(self, criteria: Callable[[_T], bool]) -> Cmd[Maybe[_T]]:
         return self._inner.new_iter.map(
             lambda i: _iter_factory.find_first(criteria, i)
-        ).map(Maybe.from_optional)
+        ).map(lambda x: Maybe.from_optional(x))
 
     def chunked(self, size: int) -> Stream[FrozenList[_T]]:
         items: Cmd[Iterable[FrozenList[_T]]] = self._inner.new_iter.map(
